# CheckPhone

This library is a vulnerable implementation of a supposed phone number validator/checker that calls subprocess in an unsecure way if phone number is provided by the user.

The reason for creating this is to simulate an RCE in a Django web app in an incident handling exercise.


## Upload new package to PyPI
- Bump version in setup.py
- 
